#!/bin/sh
# Federico Bareilles
# 13/12/2005
#
# Simple interfece for Star I on dialog.

VERSION=0.1.0
TITLE="Star I script utility v$VERSION"
CONFFILE=$HOME/.stari.conf
#USTARIPATH=$HOME/tmp
USTARIPATH=/tmp
test -d $USTARIPATH || mkdir $USTARIPATH
: ${DIALOG=dialog}
tempfile=`tempfile 2>/dev/null` || tempfile=$USTARIPATH/tmp-$$
resultfile=`resultfile 2>/dev/null` || resultfile=$USTARIPATH/result-$$
trap "rm -f $tempfile $resultfile" 0 1 2 5 15
CLEAR=""
export  ETIME GAIN 


set_etime_menu(){
    $DIALOG --backtitle "$TITLE" \
	--title "Set exposure time" $CLEAR \
        --inputbox "Enter new exposure time in secons\n
    " 8 51 2> $tempfile
    retval=$?

    case $retval in
    0)
	etime $(cat $tempfile) 2> $resultfile
	;;    
    1)
	echo "Cancel pressed." > $resultfile;;
    255)
	if test -s $tempfile ; then
	    cat $tempfile > $resultfile
	else
	    echo "ESC pressed." > $resultfile  
	fi
	;;
    esac
}

set_gain_menu(){
    if [ "$GAIN" == "1" ];then
	gain1=on
	gain4=off
    else
	gain1=of
	gain4=on
    fi
    $DIALOG --backtitle "$TITLE" \
	--title "Set gain factor" $CLEAR \
        --radiolist "Select gain factor:\n
    " 10 51 2 \
	"1"  " Gain factor is 50.0 elec/adu " $gain1 \
        "4"    " Gain factor is 12.5 elec/adu " $gain4 \
    2> $tempfile
    retval=$?

    case $retval in
    0)
	gain $(cat $tempfile) 2> $resultfile
	;;    
    1)
	echo "Cancel pressed." > $resultfile;;
    255)
	if test -s $tempfile ; then
	    cat $tempfile > $resultfile
	else
	    echo "ESC pressed." > $resultfile  
	fi
	;;
    esac
}


sequence_menu(){
    LTITLE=$3
    BASENAME=$2
    CMD=$1

    gain $GAIM
    $DIALOG --backtitle "$TITLE" \
	--title "$LTITLE" $CLEAR \
        --inputbox "Enter number of images:\n
    " 8 51 2> $tempfile
    retval=$?

    case $retval in
    0)
	echo ""> $resultfile
	info="\n"
	NUMSEQ=$(cat $tempfile)
	((for n in $(seq $NUMSEQ) ; do
	    name=$(printf "%s%03d" $BASENAME $n)
	    if [ "$CMD" != "bias" ]; then
		echo "XXX"
		echo -e "$info"
		echo "exposing ($ETIME sec.)..."
		echo "XXX"
	    fi
	    $CMD
	    echo "XXX"
	    echo "getting: $name"
	    echo "XXX"
	    #get $name >/dev/null
	    info=$(get $name) 
    	    printf "%.0f\n" $(echo "$n / $NUMSEQ * 100" | bc -l)
	done &)|\
	$DIALOG --backtitle "$TITLE" --title "$LTITLE" \
		--gauge "" 8 50 0) 2>&1 | head -n 1 > $resultfile
	;;    
    1)
	echo "Cancel pressed." > $resultfile;;
    255)
	if test -s $tempfile ; then
	    cat $tempfile > $resultfile
	else
	    echo "ESC pressed." > $resultfile  
	fi
	;;
    esac
}


main_menu(){
    $DIALOG --backtitle "$TITLE" \
	$CLEAR \
	--cancel-label " Exit " \
	--shadow \
	--title " Operations " \
        --menu "Message: $(cat $resultfile)" 18 50 11 \
	"etime"  " Exposure time ($ETIME) sec. "\
	"gain"  " Set gain factor ($GAIN) "\
	"expose" " Exposure (not get) " \
	"darkseq" " Run dark sequence " \
	"flatseq" " Run flat sequence of dome" \
	"biasseq" " Run bias sequence " \
	"exit"   " Bye " 2> $tempfile

    case $? in
	1)  clear;exit 0 ;;
	255)clear;exit 0 ;;
    esac

    case $(cat $tempfile) in
    etime)
	set_etime_menu 
	;;
    gain)
	set_gain_menu 
	;;
    expose) 
	(expose --percent $ETIME &)|\
	$DIALOG --backtitle "$TITLE" --title "Exposing" \
		--gauge "Exposure time: $ETIME sec." 6 40 0
	;;
    biasseq)
	sequence_menu "bias" "bias" "Bias sequence"
	;;
    darkseq)
	sequence_menu "dark $ETIME" "dark" "Dark sequence"
	;;
    flatseq)
	cp -f $CONFFILE $CONFFILE.back
	(cat $CONFFILE| sed "s/^OBJECT/#ustari#OBJECT/"
	echo -e "OBJECT = domeflat\t#Objet name") > $CONFFILE.tmp
	mv -f $CONFFILE.tmp $CONFFILE
	sequence_menu "flat $ETIME" "flat" "Dome flat sequence"
	mv -f $CONFFILE.back $CONFFILE
	;;
    exit)
	clear;
	exit 0
	;;
    * ) 
	return;;
    esac
}


if [ ! -f $CONFFILE ]; then
    echo -e "\nConfiguration file not found. Run stari first\n\n"
    exit 0
fi

while [ 1 ];do
    ETIME=$(etime)
    GAIN=$(gain)
    main_menu
#    case $retval in
#    0) main_menu ;;    
#    *) echo "Error: command not found."
#	exit -1;;
#    esac
done
